## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE, collapse = TRUE, cache = TRUE, fig.show = 'hold')

## ----message = FALSE----------------------------------------------------------
require(autonomics)
  rnafile <- system.file( 'extdata/billing19.rnacounts.txt',     package = 'autonomics' )
  profile <- system.file( 'extdata/billing19.proteingroups.txt', package = 'autonomics' )
  fosfile <- system.file( 'extdata/billing19.phosphosites.txt' , package = 'autonomics' )
diannfile <- download_data( 'dilution.report.tsv' )
 somafile <- system.file('extdata/atkin.somascan.adat',          package = 'autonomics')
 metafile <- system.file('extdata/atkin.metabolon.xlsx',         package = 'autonomics')

  rnaobj <- read_rnaseq_counts(         file = rnafile)
  proobj <- read_maxquant_proteingroups(file = profile)
  fosobj <- read_maxquant_phosphosites( fosfile = fosfile, profile = profile)
diannobj <- read_diann_proteingroups(   file = diannfile)
 somaobj <- read_somascan(              file = somafile)
 metaobj <- read_metabolon(             file = metafile)

## ----echo=FALSE, fig.height=6, fig.width=6, message=FALSE, out.height='85%', out.width='85%'----
require(data.table)
require(ggplot2)
require(autonomics)
dt <- data.table(
    x = 0:7, xend = 0:7, y = 2, yend = 1, 
    label = c('', 'read_affy', 'read_maxquant_proteingroups', 'read_maxquant_phosphosites', 
              'read_diann_proteingroups', 'read_somascan', 'read_metabolon', 
              'read_rnaseq_counts'), 
    molecule = c('', 'transcript', 'protein', 'protein', 'protein', 'protein', 
                 'metabolite', 'transcript'))
ggplot(dt) + 
ylim(0, 2) + 
geom_segment(aes(x = x, xend = xend, y = y, yend = yend), arrow = arrow()) + 
geom_label(aes(x = x, y = y, label = label, fill = molecule)) + 
geom_hline(aes(yintercept=1)) + 
annotate('text', x = 3, y = 0, label = 'SummarizedExperiment', hjust = 0.5) + 
theme(axis.text  = element_blank(), 
      axis.ticks = element_blank(), 
      axis.title = element_blank()) + guides(fill = 'none') + 
coord_polar() + 
scale_fill_manual(values = make_colors(unique(dt$molecule[-1]))) + 
theme_void()

## ----message = FALSE----------------------------------------------------------
file <- system.file('extdata/fukuda20.proteingroups.txt', package = 'autonomics')
object <- read_maxquant_proteingroups(file)
values(object)[1:3, 1:5]

## ----message = FALSE----------------------------------------------------------
sdt(object)[1:3, ]

## ----message = FALSE----------------------------------------------------------
fdt(object)[1:3, c(1, 2, 8)]

## -----------------------------------------------------------------------------
n <- analysis(object)$nfeature

## ----echo = FALSE-------------------------------------------------------------
require(data.table)
data.table(Filter = names(n), n = n)   # Filtering details

## ----message = FALSE, fig.with = 10, fig.height = 2.75------------------------
require(ggplot2)
d <- plot_feature_densities(object, n = 4) + guides(fill = 'none')
v <- plot_feature_violins(  object, n = 4) + guides(fill = 'none')
b <- plot_feature_boxplots( object, n = 4) + guides(fill = 'none')
gridExtra::grid.arrange(d, v, b, nrow = 1)

## ----message = FALSE, fig.with = 10, fig.height = 2.75------------------------
require(ggplot2)
d <- plot_sample_densities(object) + guides(fill = 'none')
v <- plot_sample_violins(object)   + guides(fill = 'none')
b <- plot_sample_boxplots(object)  + guides(fill = 'none')
gridExtra::grid.arrange(d, v, b, nrow = 1)

## ----message = FALSE, fig.width = 3.5, fig.height = 2.5, out.width = '50%', out.height = '50%'----
biplot(pca(object))

## -----------------------------------------------------------------------------
systematic <- sum(systematic_nas(object))
random     <-     sum(random_nas(object))
no         <-         sum(no_nas(object))

## ----echo = TRUE, results = 'hide', message = FALSE, fig.width = 6, fig.height = 3, out.width = '100%', out.height = '100%'----
p1 <- plot_sample_nas(object) + ggplot2::guides(fill = 'none')
p2 <- plot_subgroup_nas(object)
gridExtra::grid.arrange(p1, p2, nrow = 1)

## ----echo = TRUE, results = 'hide', message = FALSE, fig.cap = 'Left: sample distributions, Right: detections'----
require(magrittr)
object %<>% impute(plot = TRUE)

## -----------------------------------------------------------------------------
table(object$subgroup)

## -----------------------------------------------------------------------------
  require(magrittr)
  object %<>% fit_lm()

## ----echo = FALSE, message = FALSE--------------------------------------------
  summary <- summarize_fit(fdt(object), fit = 'lm')
  systime <- system.time(object %<>% fit_lm())

## ----eval = FALSE-------------------------------------------------------------
#  object %<>% fit_lm()
#  object %<>% fit_lm(formula = ~ subgroup)

## ----fig.width = 5, fig.height = 3, out.width='70%', out.height='70%'---------
plot_design(object)

## ----message = FALSE----------------------------------------------------------
file <- system.file('extdata/fukuda20.proteingroups.txt', package = 'autonomics')
object <- read_maxquant_proteingroups(file)
object %<>% fit_limma(formula   = ~ 0 + subgroup, contrasts = c('Adult - X30dpt'))

